==> vtk-v4.0.2.zip: vtk-v4.0.2/Rendering/vtkMesaImageActor.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkMesaImageActor.cxx
  Language:  C++
  Date:      $Date$
  Version:   $Revision$


Copyright (c) 1993-2001 Ken Martin, Will Schroeder, Bill Lorensen 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither name of Ken Martin, Will Schroeder, or Bill Lorensen nor the names
   of any contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// This keeps the New method from being defined in included cxx file.
#define VTK_IMPLEMENT_MESA_CXX
#include "MangleMesaInclude/gl_mangle.h"
#include "MangleMesaInclude/gl.h"

#include <math.h>
#include "vtkToolkits.h"
#include "vtkMesaImageActor.h"
#include "vtkRenderWindow.h"
#include "vtkMesaProperty.h"
#include "vtkMesaCamera.h"
#include "vtkMesaLight.h"
#include "vtkCuller.h"


// make sure this file is included before the #define takes place
// so we don't get two vtkMesaImageActor classes defined.
#include "vtkOpenGLImageActor.h"
#include "vtkMesaImageActor.h"

// Make sure vtkMesaImageActor is a copy of vtkOpenGLImageActor
// with vtkOpenGLImageActor replaced with vtkMesaImageActor
#define vtkOpenGLImageActor vtkMesaImageActor
#define vtkOpenGLRenderWindow vtkMesaRenderWindow
#include "vtkOpenGLImageActor.cxx"
#undef vtkOpenGLImageActor
#undef vtkOpenGLRenderWindow

//-----------------------------------------------------------------------------
vtkMesaImageActor* vtkMesaImageActor::New()
{
  // First try to create the object from the vtkObjectFactory
  vtkObject* ret = vtkObjectFactory::CreateInstance("vtkMesaImageActor");
  if(ret)
    {
    return (vtkMesaImageActor*)ret;
    }
  // If the factory was unable to create the object, then create it here.
  return new vtkMesaImageActor;
}

==> vtk-v5.6.0.zip: vtk-v5.6.0/Rendering/vtkMesaImageActor.cxx <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkMesaImageActor.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// This keeps the New method from being defined in included cxx file.
#define VTK_IMPLEMENT_MESA_CXX
#include "MangleMesaInclude/gl_mangle.h"
#include "MangleMesaInclude/gl.h"

#include <math.h>
#include "vtkToolkits.h"
#include "vtkMesaImageActor.h"
#include "vtkRenderWindow.h"
#include "vtkMesaProperty.h"
#include "vtkMesaCamera.h"
#include "vtkMesaLight.h"
#include "vtkCuller.h"


// make sure this file is included before the #define takes place
// so we don't get two vtkMesaImageActor classes defined.
#include "vtkOpenGLImageActor.h"
#include "vtkMesaImageActor.h"

// Make sure vtkMesaImageActor is a copy of vtkOpenGLImageActor
// with vtkOpenGLImageActor replaced with vtkMesaImageActor
#define vtkOpenGLImageActor vtkMesaImageActor
#define vtkOpenGLRenderWindow vtkMesaRenderWindow
#include "vtkOpenGLImageActor.cxx"
#undef vtkOpenGLImageActor
#undef vtkOpenGLRenderWindow

vtkCxxRevisionMacro(vtkMesaImageActor, "1.11");
vtkStandardNewMacro(vtkMesaImageActor);
